@@ -36,8 +36,9 @@ def setup_logging(path: str or Path = 'logging.json'):
 def main_loop(config_path: str = None):
     setup_logging()
     fh = FindHome(config_path)
+    delay = fh.config.delay
     while True:
-        time.sleep(5)
+        time.sleep(delay)
         fh.check()
 
 
